@@ -6,8 +6,8 @@ Auditory localizor experiment. Subject listen to 100 trial of 1kHz pure tone wit
 900ms to 1200ms. EEG recorded with BP actiChamp, 32 sensors, standard 1020 layout, EasyCap 32, PyCoder.
 Format: Bp '.vhdr'. Sample rate: 1000Hz. Referenced at Cz. Eog: 'AF3','AF7'.
 '''
-
-from rest_ref import *
+from restpython import *
+import mne
 import matplotlib
 matplotlib.use('TkAgg')
 
